Index: libs/libmyth/mythcontext.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/libs/libmyth/mythcontext.cpp,v
retrieving revision 1.137
diff -u -r1.137 mythcontext.cpp
--- libs/libmyth/mythcontext.cpp	6 Nov 2004 17:36:43 -0000	1.137
+++ libs/libmyth/mythcontext.cpp	5 Dec 2004 19:49:20 -0000
@@ -27,6 +27,16 @@
 #include "screensaver.h"
 #include "DisplayRes.h"
 
+// These defines provide portability for different
+// plugin file names.
+#ifdef CONFIG_DARWIN
+const QString kPluginLibPrefix = "lib";
+const QString kPluginLibSuffix = ".dylib";
+#else
+const QString kPluginLibPrefix = "lib";
+const QString kPluginLibSuffix = ".so";
+#endif
+
 MythContext *gContext = NULL;
 
 int print_verbose_messages = VB_IMPORTANT | VB_GENERAL;
@@ -364,6 +374,66 @@
     return d->m_installprefix + "/share/mythtv/"; 
 }
 
+QString MythContext::GetLibraryDir(void) 
+{ 
+    return d->m_installprefix + "/lib/mythtv/"; 
+}
+
+QString MythContext::GetThemesParentDir(void) 
+{ 
+    return GetShareDir() + "themes/"; 
+}
+
+QString MythContext::GetPluginsDir(void) 
+{ 
+    return GetLibraryDir() + "plugins/"; 
+}
+
+QString MythContext::GetPluginsNameFilter(void) 
+{ 
+    return kPluginLibPrefix + "*" + kPluginLibSuffix; 
+}
+
+QString MythContext::FindPlugin(const QString &plugname) 
+{ 
+    return GetPluginsDir() + kPluginLibPrefix + plugname + kPluginLibSuffix; 
+}
+
+QString MythContext::GetTranslationsDir(void) 
+{ 
+    return GetShareDir() + "i18n/"; 
+}
+
+QString MythContext::GetTranslationsNameFilter(void) 
+{ 
+    return "mythfrontend_*.qm"; 
+}
+
+QString MythContext::FindTranslation(const QString &translation) 
+{ 
+    return GetTranslationsDir() + "mythfrontend_" + translation.lower() + ".qm"; 
+}
+
+QString MythContext::GetFontsDir(void) 
+{ 
+    return GetShareDir();
+}
+
+QString MythContext::GetFontsNameFilter(void) 
+{ 
+    return "*ttf"; 
+}
+
+QString MythContext::FindFont(const QString &fontname) 
+{ 
+    return GetFontsDir() + fontname + ".ttf"; 
+}
+
+QString MythContext::GetFiltersDir(void) 
+{ 
+    return GetLibraryDir() + "filters/"; 
+}
+
 bool MythContext::LoadSettingsFiles(const QString &filename)
 {
     return d->m_settings->LoadSettingsFiles(filename, d->m_installprefix);
Index: libs/libmyth/mythcontext.h
===================================================================
RCS file: /var/lib/mythcvs/mythtv/libs/libmyth/mythcontext.h,v
retrieving revision 1.172
diff -u -r1.172 mythcontext.h
--- libs/libmyth/mythcontext.h	30 Nov 2004 02:27:22 -0000	1.172
+++ libs/libmyth/mythcontext.h	5 Dec 2004 19:49:20 -0000
@@ -134,6 +134,7 @@
 
     QString GetInstallPrefix(void);
     QString GetShareDir(void);
+    QString GetLibraryDir(void);
 
     QString GetFilePrefix(void);
 
@@ -154,6 +155,22 @@
 
     QString GetMenuThemeDir(void);
 
+    QString GetThemesParentDir(void);
+
+    QString GetPluginsDir(void);
+    QString GetPluginsNameFilter(void);
+    QString FindPlugin(const QString &plugname);
+
+    QString GetTranslationsDir(void);
+    QString GetTranslationsNameFilter(void);
+    QString FindTranslation(const QString &translation);
+
+    QString GetFontsDir(void);
+    QString GetFontsNameFilter(void);
+    QString FindFont(const QString &fontname);
+
+    QString GetFiltersDir(void);
+
     int OpenDatabase(QSqlDatabase *db);
     static void KickDatabase(QSqlDatabase *db);
     static void DBError(const QString &where, const QSqlQuery& query);
Index: libs/libmyth/mythplugin.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/libs/libmyth/mythplugin.cpp,v
retrieving revision 1.13
diff -u -r1.13 mythplugin.cpp
--- libs/libmyth/mythplugin.cpp	12 Nov 2004 16:35:48 -0000	1.13
+++ libs/libmyth/mythplugin.cpp	5 Dec 2004 19:49:20 -0000
@@ -9,16 +9,6 @@
 
 using namespace std;
 
-// These defines provide portability for different
-// plugin file names.
-#ifdef CONFIG_DARWIN
-const QString kPluginLibPrefix = "lib";
-const QString kPluginLibSuffix = ".dylib";
-#else
-const QString kPluginLibPrefix = "lib";
-const QString kPluginLibSuffix = ".so";
-#endif
-
 MythPlugin::MythPlugin(const QString &libname)
           : QLibrary(libname)
 {
@@ -95,17 +85,21 @@
 {
     m_dict.setAutoDelete(true);
 
-    QString pluginprefix = QString(PREFIX) + "/lib/mythtv/plugins/";
+    QString pluginprefix = gContext->GetPluginsDir();
 
     QDir filterDir(pluginprefix);
 
     filterDir.setFilter(QDir::Files | QDir::Readable);
-    filterDir.setNameFilter(kPluginLibPrefix + "*" + kPluginLibSuffix);
+    QString filter = gContext->GetPluginsNameFilter();
+    filterDir.setNameFilter(filter);
 
     gContext->SetDisableLibraryPopup(true);
 
     if (filterDir.exists())
     {
+        int prefixLength = filter.find("*");
+        int suffixLength = filter.length() - prefixLength - 1;
+
         QStringList libraries = filterDir.entryList();
         for (QStringList::iterator i = libraries.begin(); i != libraries.end();
              i++)
@@ -113,8 +107,8 @@
             QString library = *i;
 
             // pull out the base library name
-            library = library.right(library.length() - kPluginLibPrefix.length());
-            library = library.left(library.length() - kPluginLibSuffix.length());
+            library = library.right(library.length() - prefixLength);
+            library = library.left(library.length() - suffixLength);
 
             init_plugin(library);
         }
@@ -127,8 +121,7 @@
 
 bool MythPluginManager::init_plugin(const QString &plugname)
 {
-    QString newname = QString(PREFIX) + "/lib/mythtv/plugins/" +
-                      kPluginLibPrefix + plugname + kPluginLibSuffix;
+    QString newname = gContext->FindPlugin(plugname);
    
     if (m_dict.find(newname) == 0)
     {
@@ -161,8 +154,7 @@
 
 bool MythPluginManager::run_plugin(const QString &plugname)
 {
-    QString newname = QString(PREFIX) + "/lib/mythtv/plugins/" +
-                      kPluginLibPrefix + plugname + kPluginLibSuffix;
+    QString newname = gContext->FindPlugin(plugname);
 
     if (m_dict.find(newname) == 0 && init_plugin(plugname) == false)
     {
@@ -177,8 +169,7 @@
 
 bool MythPluginManager::config_plugin(const QString &plugname)
 {
-    QString newname = QString(PREFIX) + "/lib/mythtv/plugins/lib" + plugname +
-                      ".so";
+    QString newname = gContext->FindPlugin(plugname);
 
     if (m_dict.find(newname) == 0 && init_plugin(plugname) == false)
     {
@@ -193,8 +184,7 @@
 
 MythPlugin *MythPluginManager::GetPlugin(const QString &plugname)
 {
-    QString newname = QString(PREFIX) + "/lib/mythtv/plugins/lib" + plugname +
-                      ".so";
+    QString newname = gContext->FindPlugin(plugname);
 
     if (moduleMap.find(newname) == moduleMap.end())
         return NULL;
@@ -204,8 +194,7 @@
 
 MythPlugin *MythPluginManager::GetMenuPlugin(const QString &plugname)
 {
-    QString newname = QString(PREFIX) + "/lib/mythtv/plugins/lib" + plugname +
-                      ".so";
+    QString newname = gContext->FindPlugin(plugname);
 
     if (menuPluginMap.find(newname) == menuPluginMap.end())
         return NULL;
Index: libs/libmyth/themedmenu.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/libs/libmyth/themedmenu.cpp,v
retrieving revision 1.98
diff -u -r1.98 themedmenu.cpp
--- libs/libmyth/themedmenu.cpp	26 Nov 2004 14:07:43 -0000	1.98
+++ libs/libmyth/themedmenu.cpp	5 Dec 2004 19:49:20 -0000
@@ -2412,8 +2412,7 @@
         if (filename != "")
             return true;
     
-        QString newname = QString(PREFIX) + "/lib/mythtv/plugins/lib" + *it +
-                          ".so";
+        QString newname = gContext->FindPlugin(*it);
     
         QFile checkFile(newname);
         if (checkFile.exists())
Index: libs/libmythtv/filter.h
===================================================================
RCS file: /var/lib/mythcvs/mythtv/libs/libmythtv/filter.h,v
retrieving revision 1.6
diff -u -r1.6 filter.h
--- libs/libmythtv/filter.h	13 Jan 2004 07:37:34 -0000	1.6
+++ libs/libmythtv/filter.h	5 Dec 2004 19:49:20 -0000
@@ -7,8 +7,6 @@
 
 #include "frame.h"
 
-#define MYTHTV_FILTER_PATH PREFIX"/lib/mythtv/filters"
-
 typedef struct FmtConv_
 {
     VideoFrameType in;
Index: libs/libmythtv/filtermanager.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/libs/libmythtv/filtermanager.cpp,v
retrieving revision 1.13
diff -u -r1.13 filtermanager.cpp
--- libs/libmythtv/filtermanager.cpp	23 Nov 2004 19:08:15 -0000	1.13
+++ libs/libmythtv/filtermanager.cpp	5 Dec 2004 19:49:20 -0000
@@ -66,7 +66,7 @@
 
 FilterManager::FilterManager()
 {
-    QDir FiltDir(MYTHTV_FILTER_PATH);
+    QDir FiltDir(gContext->GetFiltersDir());
     QString Path;
 
     FiltDir.setFilter(QDir::Files | QDir::Readable);
Index: libs/libmythui/themedmenu.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/libs/libmythui/themedmenu.cpp,v
retrieving revision 1.3
diff -u -r1.3 themedmenu.cpp
--- libs/libmythui/themedmenu.cpp	13 Sep 2004 20:57:49 -0000	1.3
+++ libs/libmythui/themedmenu.cpp	5 Dec 2004 19:49:21 -0000
@@ -2083,8 +2083,7 @@
     if (filename != "")
         return true;
 
-    QString newname = QString(PREFIX) + "/lib/mythtv/plugins/lib" + file +
-                      ".so";
+    QString newname = gContext->FindPlugin(file);
 
     QFile checkFile(newname);
     if (checkFile.exists())
Index: programs/mythfrontend/globalsettings.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/programs/mythfrontend/globalsettings.cpp,v
retrieving revision 1.203
diff -u -r1.203 globalsettings.cpp
--- programs/mythfrontend/globalsettings.cpp	24 Nov 2004 06:12:32 -0000	1.203
+++ programs/mythfrontend/globalsettings.cpp	5 Dec 2004 19:49:21 -0000
@@ -666,7 +666,7 @@
     GenericComboBox *gc = new GenericComboBox("MenuTheme");
     gc->setLabel(QObject::tr("Menu theme"));
 
-    QDir themes(PREFIX"/share/mythtv/themes");
+    QDir themes(gContext->GetThemesParentDir());
     themes.setFilter(QDir::Dirs);
     themes.setSorting(QDir::Name | QDir::IgnoreCase);
     gc->addSelection(QObject::tr("Default"));
@@ -693,7 +693,7 @@
     GenericComboBox *gc = new GenericComboBox("OSDTheme");
     gc->setLabel(QObject::tr("OSD theme"));
 
-    QDir themes(PREFIX"/share/mythtv/themes");
+    QDir themes(gContext->GetThemesParentDir());
     themes.setFilter(QDir::Dirs);
     themes.setSorting(QDir::Name | QDir::IgnoreCase);
 
@@ -719,7 +719,7 @@
 {
     GenericComboBox *gc = new GenericComboBox("OSDFont");
     gc->setLabel(QObject::tr("OSD font"));
-    QDir ttf(PREFIX"/share/mythtv", "*ttf");
+    QDir ttf(gContext->GetFontsDir(), gContext->GetFontsNameFilter());
     gc->fillSelectionsFromDir(ttf, false);
 
     return gc;
@@ -729,7 +729,7 @@
 {
     GenericComboBox *gc = new GenericComboBox("OSDCCFont");
     gc->setLabel(QObject::tr("Closed Caption font"));
-    QDir ttf(PREFIX"/share/mythtv", "*ttf");
+    QDir ttf(gContext->GetFontsDir(), gContext->GetFontsNameFilter());
     gc->fillSelectionsFromDir(ttf, false);
 
     return gc;
@@ -1474,7 +1474,7 @@
 
     setLabel(QObject::tr("Theme"));
 
-    QDir themes(PREFIX"/share/mythtv/themes");
+    QDir themes(gContext->GetThemesParentDir());
     themes.setFilter(QDir::Dirs);
     themes.setSorting(QDir::Name | QDir::IgnoreCase);
 
Index: programs/mythfrontend/main.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/programs/mythfrontend/main.cpp,v
retrieving revision 1.176
diff -u -r1.176 main.cpp
--- programs/mythfrontend/main.cpp	20 Nov 2004 06:00:36 -0000	1.176
+++ programs/mythfrontend/main.cpp	5 Dec 2004 19:49:22 -0000
@@ -384,9 +384,9 @@
         settings.exec(QSqlDatabase::database());
 
         qApp->removeTranslator(translator);
-        translator->load(PREFIX + QString("/share/mythtv/i18n/mythfrontend_") +
-                         QString(gContext->GetSetting("Language").lower()) +
-                         QString(".qm"), ".");
+        translator->load(
+            gContext->FindTranslation(gContext->GetSetting("Language")),
+            ".");
         qApp->installTranslator(translator);
 
         gContext->LoadQtConfig();
@@ -538,7 +538,7 @@
 
 QString RandTheme(QString &themename, QSqlDatabase *db)
 {
-    QDir themes(PREFIX"/share/mythtv/themes");
+    QDir themes(gContext->GetThemesParentDir());
     themes.setFilter(QDir::Dirs);
 
     const QFileInfoList *fil = themes.entryInfoList(QDir::Dirs);
@@ -971,9 +971,9 @@
             lcd->setupLEDs(RemoteGetRecordingMask);
     }
 
-    translator->load(PREFIX + QString("/share/mythtv/i18n/mythfrontend_") + 
-                     QString(gContext->GetSetting("Language").lower()) + 
-                     QString(".qm"), ".");
+    translator->load(
+        gContext->FindTranslation(gContext->GetSetting("Language")),
+        ".");
     a.installTranslator(translator);
 
     WriteDefaults(db);
Index: setup/main.cpp
===================================================================
RCS file: /var/lib/mythcvs/mythtv/setup/main.cpp,v
retrieving revision 1.48
diff -u -r1.48 main.cpp
--- setup/main.cpp	30 Nov 2004 01:07:39 -0000	1.48
+++ setup/main.cpp	5 Dec 2004 19:49:22 -0000
@@ -122,9 +122,9 @@
 
     UpgradeTVDatabaseSchema();
 
-    translator->load(PREFIX + QString("/share/mythtv/i18n/mythfrontend_") + 
-                     QString(gContext->GetSetting("Language").lower()) + 
-                     QString(".qm"), ".");
+    translator->load(
+        gContext->FindTranslation(gContext->GetSetting("Language")),
+        ".");
     a.installTranslator(translator);
 
     gContext->SetSetting("Theme", "blue");
